"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var t = __importStar(require("@babel/types"));
var ast_builders_1 = require("../utils/ast-builders");
var css_builders_1 = require("../utils/css-builders");
var getJsxAttributeExpression = function (node) {
    if (t.isStringLiteral(node.value)) {
        return node.value;
    }
    if (t.isJSXExpressionContainer(node.value)) {
        return node.value.expression;
    }
    throw new Error('Value of JSX attribute was unexpected.');
};
/**
 * Takes a JSX opening element and then transforms any usage of `css` prop to a compiled component.
 *
 * `<div css={{}}>`
 *
 * @param path Babel path - expects to be a JSX opening element.
 * @param state Babel state - should house options and meta data used during the transformation.
 */
exports.visitCssPropPath = function (path, meta) {
    var cssPropIndex = -1;
    var cssProp = path.node.attributes.find(function (attr, index) {
        if (t.isJSXAttribute(attr) && attr.name.name === 'css') {
            cssPropIndex = index;
            return true;
        }
        return false;
    });
    if (!cssProp || !cssProp.value) {
        return;
    }
    var cssOutput = css_builders_1.buildCss(getJsxAttributeExpression(cssProp), meta);
    // Remove css prop
    path.node.attributes.splice(cssPropIndex, 1);
    if (!cssOutput.css.length) {
        // No css was generated - return early!
        return;
    }
    path.parentPath.replaceWith(ast_builders_1.buildCompiledComponent(path.parentPath.node, cssOutput, meta));
};
//# sourceMappingURL=index.js.map